# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['src']

package_data = \
{'': ['*']}

install_requires = \
['click==8.1.8', 'ollama==0.4.7']

entry_points = \
{'console_scripts': ['runllama = src.main:runner']}

setup_kwargs = {
    'name': 'runllama',
    'version': '0.1.0',
    'description': 'Simple CLI runner for Ollama (LLM) models',
    'long_description': '# RunLlama\n\nSimple CLI tool for [Ollama (LLM) models](https://ollama.com/search).\n\n## Installation\n\nInstall via pip:\n\n```bash\npip install runllama\n```\n\nOr with Poetry:\n\n```bash\npoetry add runllama\n```\n\nRun the CLI:\n\n```bash\nrunllama --help\n```\n\n## For Development\n\nBuild and run ollama server docker container\n\n```bash\ndocker build -t runllama .\ndocker run -d -p 11434:11434 -v ollama:/app/.ollama --name runllama runllama \n```\n\nInstall dependencies\n\n```bash\npoetry install\npoetry shell\n```\n\nRun Python script\n\n```bash\npython src/main.py --help\n```\n\n## License\n\nThe extension source code is licensed under the MIT License (see [LICENSE](LICENSE)).\n',
    'author': 'Manasseh',
    'author_email': 'believemanasseh@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
